@@ -4,6 +4,15 @@ use thiserror::Error;
 
 #[derive(Error, Debug, PartialEq)]
 pub enum Error {
+    #[error("Invalid Parent RTCP Reader")]
+    ErrInvalidParentRtcpReader,
+    #[error("Incorrect ReceiverReport CloseRx")]
+    ErrIncorrectReceiverReportCloseRx,
+    #[error("IO EOF")]
+    ErrIoEOF,
+    #[error("Buffer is too short")]
+    ErrShortBuffer,
+
     #[allow(non_camel_case_types)]
     #[error("{0}")]
     new(String),
